Class: GraphQL::Language::DocumentFromSchemaDefinition Private

Inherits:
Object
  • Object
show all
Defined in:
lib/graphql/language/document_from_schema_definition.rb

Overview

This class is part of a private API. You should avoid using this class if possible, as it may be removed or be changed in the future.

DocumentFromSchemaDefinition is used to convert a Schema object To a Document AST node.

API:

  • private

Instance Method Summary collapse

Constructor Details

#initialize(schema, context: nil, only: nil, except: nil, include_introspection_types: false, include_built_in_directives: false, include_built_in_scalars: false, always_include_schema: false) ⇒ DocumentFromSchemaDefinition

This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.

Returns a new instance of DocumentFromSchemaDefinition.

API:

  • private



16
17
18
19
20
21
22
23
24
25
26
27
28
29
30
31
32
33
34
35
36
37
38
# File 'lib/graphql/language/document_from_schema_definition.rb', line 16

def initialize(
  schema, context: nil, only: nil, except: nil, include_introspection_types: false,
  include_built_in_directives: false, include_built_in_scalars: false, always_include_schema: false
)
  @schema = schema
  @always_include_schema = always_include_schema
  @include_introspection_types = include_introspection_types
  @include_built_in_scalars = include_built_in_scalars
  @include_built_in_directives = include_built_in_directives

  filter = GraphQL::Filter.new(only: only, except: except)
  if @schema.respond_to?(:visible?)
    filter = filter.merge(only: @schema.method(:visible?))
  end

  schema_context = schema.context_class.new(query: nil, object: nil, schema: schema, values: context)
  @warden = GraphQL::Schema::Warden.new(
    filter,
    schema: @schema,
    context: schema_context,
  )
  schema_context.warden = @warden
end

Instance Method Details

#build_argument_node(argument) ⇒ Object

This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.

API:

  • private



125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
# File 'lib/graphql/language/document_from_schema_definition.rb', line 125

def build_argument_node(argument)
  if argument.default_value?
    default_value = build_default_value(argument.default_value, argument.type)
  else
    default_value = nil
  end

  argument_node = GraphQL::Language::Nodes::InputValueDefinition.new(
    name: argument.graphql_name,
    description: argument.description,
    type: build_type_name_node(argument.type),
    default_value: default_value,
    directives: directives(argument),
  )

  argument_node
end

#build_argument_nodes(arguments) ⇒ Object

This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.

API:

  • private



234
235
236
237
238
# File 'lib/graphql/language/document_from_schema_definition.rb', line 234

def build_argument_nodes(arguments)
  arguments
    .map { |arg| build_argument_node(arg) }
    .sort_by(&:name)
end

#build_default_value(default_value, type) ⇒ Object

This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.

API:

  • private



186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
# File 'lib/graphql/language/document_from_schema_definition.rb', line 186

def build_default_value(default_value, type)
  if default_value.nil?
    return GraphQL::Language::Nodes::NullValue.new(name: "null")
  end

  case type.kind.name
  when "SCALAR"
    type.coerce_isolated_result(default_value)
  when "ENUM"
    GraphQL::Language::Nodes::Enum.new(name: type.coerce_isolated_result(default_value))
  when "INPUT_OBJECT"
    GraphQL::Language::Nodes::InputObject.new(
      arguments: default_value.to_h.map do |arg_name, arg_value|
        arg_type = @warden.arguments(type).find { |a| a.graphql_name == arg_name.to_s }.type
        GraphQL::Language::Nodes::Argument.new(
          name: arg_name.to_s,
          value: build_default_value(arg_value, arg_type)
        )
      end
    )
  when "NON_NULL"
    build_default_value(default_value, type.of_type)
  when "LIST"
    default_value.to_a.map { |v| build_default_value(v, type.of_type) }
  else
    raise GraphQL::RequiredImplementationMissingError, "Unexpected default value type #{type.inspect}"
  end
end

#build_definition_nodesObject

This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.

API:

  • private



250
251
252
253
254
255
256
# File 'lib/graphql/language/document_from_schema_definition.rb', line 250

def build_definition_nodes
  definitions = []
  definitions << build_schema_node if include_schema_node?
  definitions += build_directive_nodes(warden.directives)
  definitions += build_type_definition_nodes(warden.reachable_types)
  definitions
end

#build_directive_location_node(location) ⇒ Object

This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.

API:

  • private



165
166
167
168
169
# File 'lib/graphql/language/document_from_schema_definition.rb', line 165

def build_directive_location_node(location)
  GraphQL::Language::Nodes::DirectiveLocation.new(
    name: location.to_s
  )
end

#build_directive_location_nodes(locations) ⇒ Object

This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.

API:

  • private



161
162
163
# File 'lib/graphql/language/document_from_schema_definition.rb', line 161

def build_directive_location_nodes(locations)
  locations.sort.map { |location| build_directive_location_node(location) }
end

#build_directive_node(directive) ⇒ Object

This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.

API:

  • private



152
153
154
155
156
157
158
159
# File 'lib/graphql/language/document_from_schema_definition.rb', line 152

def build_directive_node(directive)
  GraphQL::Language::Nodes::DirectiveDefinition.new(
    name: directive.graphql_name,
    arguments: build_argument_nodes(warden.arguments(directive)),
    locations: build_directive_location_nodes(directive.locations),
    description: directive.description,
  )
end

#build_directive_nodes(directives) ⇒ Object

This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.

API:

  • private



240
241
242
243
244
245
246
247
248
# File 'lib/graphql/language/document_from_schema_definition.rb', line 240

def build_directive_nodes(directives)
  if !include_built_in_directives
    directives = directives.reject { |directive| directive.default_directive? }
  end

  directives
    .map { |directive| build_directive_node(directive) }
    .sort_by(&:name)
end

#build_enum_type_node(enum_type) ⇒ Object

This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.

API:

  • private



98
99
100
101
102
103
104
105
106
107
# File 'lib/graphql/language/document_from_schema_definition.rb', line 98

def build_enum_type_node(enum_type)
  GraphQL::Language::Nodes::EnumTypeDefinition.new(
    name: enum_type.graphql_name,
    values: warden.enum_values(enum_type).sort_by(&:graphql_name).map do |enum_value|
      build_enum_value_node(enum_value)
    end,
    description: enum_type.description,
    directives: directives(enum_type),
  )
end

#build_enum_value_node(enum_value) ⇒ Object

This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.

API:

  • private



109
110
111
112
113
114
115
# File 'lib/graphql/language/document_from_schema_definition.rb', line 109

def build_enum_value_node(enum_value)
  GraphQL::Language::Nodes::EnumValueDefinition.new(
    name: enum_value.graphql_name,
    description: enum_value.description,
    directives: directives(enum_value),
  )
end

#build_field_node(field) ⇒ Object

This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.

API:

  • private



69
70
71
72
73
74
75
76
77
# File 'lib/graphql/language/document_from_schema_definition.rb', line 69

def build_field_node(field)
  GraphQL::Language::Nodes::FieldDefinition.new(
    name: field.graphql_name,
    arguments: build_argument_nodes(warden.arguments(field)),
    type: build_type_name_node(field.type),
    description: field.description,
    directives: directives(field),
  )
end

#build_field_nodes(fields) ⇒ Object

This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.

API:

  • private



272
273
274
275
276
# File 'lib/graphql/language/document_from_schema_definition.rb', line 272

def build_field_nodes(fields)
  fields
    .map { |field| build_field_node(field) }
    .sort_by(&:name)
end

#build_input_object_node(input_object) ⇒ Object

This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.

API:

  • private



143
144
145
146
147
148
149
150
# File 'lib/graphql/language/document_from_schema_definition.rb', line 143

def build_input_object_node(input_object)
  GraphQL::Language::Nodes::InputObjectTypeDefinition.new(
    name: input_object.graphql_name,
    fields: build_argument_nodes(warden.arguments(input_object)),
    description: input_object.description,
    directives: directives(input_object),
  )
end

#build_interface_type_node(interface_type) ⇒ Object

This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.

API:

  • private



88
89
90
91
92
93
94
95
96
# File 'lib/graphql/language/document_from_schema_definition.rb', line 88

def build_interface_type_node(interface_type)
  GraphQL::Language::Nodes::InterfaceTypeDefinition.new(
    name: interface_type.graphql_name,
    interfaces: warden.interfaces(interface_type).sort_by(&:graphql_name).map { |type| build_type_name_node(type) },
    description: interface_type.description,
    fields: build_field_nodes(warden.fields(interface_type)),
    directives: directives(interface_type),
  )
end

#build_object_type_node(object_type) ⇒ Object

This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.

API:

  • private



59
60
61
62
63
64
65
66
67
# File 'lib/graphql/language/document_from_schema_definition.rb', line 59

def build_object_type_node(object_type)
  GraphQL::Language::Nodes::ObjectTypeDefinition.new(
    name: object_type.graphql_name,
    interfaces: warden.interfaces(object_type).sort_by(&:graphql_name).map { |iface| build_type_name_node(iface) },
    fields: build_field_nodes(warden.fields(object_type)),
    description: object_type.description,
    directives: directives(object_type),
  )
end

#build_scalar_type_node(scalar_type) ⇒ Object

This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.

API:

  • private



117
118
119
120
121
122
123
# File 'lib/graphql/language/document_from_schema_definition.rb', line 117

def build_scalar_type_node(scalar_type)
  GraphQL::Language::Nodes::ScalarTypeDefinition.new(
    name: scalar_type.graphql_name,
    description: scalar_type.description,
    directives: directives(scalar_type),
  )
end

#build_schema_nodeObject

This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.

API:

  • private



46
47
48
49
50
51
52
53
54
55
56
57
# File 'lib/graphql/language/document_from_schema_definition.rb', line 46

def build_schema_node
  GraphQL::Language::Nodes::SchemaDefinition.new(
    query: (q = warden.root_type_for_operation("query")) && q.graphql_name,
    mutation: (m = warden.root_type_for_operation("mutation")) && m.graphql_name,
    subscription: (s = warden.root_type_for_operation("subscription")) && s.graphql_name,
    # This only supports directives from parsing,
    # use a custom printer to add to this list.
    #
    # `@schema.directives` is covered by `build_definition_nodes`
    directives: ast_directives(@schema),
  )
end

#build_type_definition_node(type) ⇒ Object

This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.

API:

  • private



215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
# File 'lib/graphql/language/document_from_schema_definition.rb', line 215

def build_type_definition_node(type)
  case type.kind.name
  when "OBJECT"
    build_object_type_node(type)
  when "UNION"
    build_union_type_node(type)
  when "INTERFACE"
    build_interface_type_node(type)
  when "SCALAR"
    build_scalar_type_node(type)
  when "ENUM"
    build_enum_type_node(type)
  when "INPUT_OBJECT"
    build_input_object_node(type)
  else
    raise TypeError
  end
end

#build_type_definition_nodes(types) ⇒ Object

This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.

API:

  • private



258
259
260
261
262
263
264
265
266
267
268
269
270
# File 'lib/graphql/language/document_from_schema_definition.rb', line 258

def build_type_definition_nodes(types)
  if !include_introspection_types
    types = types.reject { |type| type.introspection? }
  end

  if !include_built_in_scalars
    types = types.reject { |type| type.kind.scalar? && type.default_scalar? }
  end

  types
    .map { |type| build_type_definition_node(type) }
    .sort_by(&:name)
end

#build_type_name_node(type) ⇒ Object

This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.

API:

  • private



171
172
173
174
175
176
177
178
179
180
181
182
183
184
# File 'lib/graphql/language/document_from_schema_definition.rb', line 171

def build_type_name_node(type)
  case type.kind.name
  when "LIST"
    GraphQL::Language::Nodes::ListType.new(
      of_type: build_type_name_node(type.of_type)
    )
  when "NON_NULL"
    GraphQL::Language::Nodes::NonNullType.new(
      of_type: build_type_name_node(type.of_type)
    )
  else
    GraphQL::Language::Nodes::TypeName.new(name: type.graphql_name)
  end
end

#build_union_type_node(union_type) ⇒ Object

This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.

API:

  • private



79
80
81
82
83
84
85
86
# File 'lib/graphql/language/document_from_schema_definition.rb', line 79

def build_union_type_node(union_type)
  GraphQL::Language::Nodes::UnionTypeDefinition.new(
    name: union_type.graphql_name,
    description: union_type.description,
    types: warden.possible_types(union_type).sort_by(&:graphql_name).map { |type| build_type_name_node(type) },
    directives: directives(union_type),
  )
end

#documentObject

This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.

API:

  • private



40
41
42
43
44
# File 'lib/graphql/language/document_from_schema_definition.rb', line 40

def document
  GraphQL::Language::Nodes::Document.new(
    definitions: build_definition_nodes
  )
end